macro_rules! event_types {
($event_ty:ty, [$($events:ty),+]) => { ... };
}Expand description
A convenient macro to get the list of event types as a list of &'static str.
It performs compile-time checks to guarantee that the specified variants exist.